import { TextInput, useForm } from '../../form'
import { prepareDataForDB } from '../../training/utils'
import { File, useUpdateFileMutation, useUploadFileMutation } from '../../gql'
import { customEvent } from '../../lib/customEvent'
import { ChangeEvent, useState } from 'react'
import { useRouter } from 'next/router'
import { FontAwesomeIcon } from '@fortawesome/react-fontawesome'
import { faLink } from '@fortawesome/free-solid-svg-icons'
import { PlayButton } from '../../audioplayer'

const EditFile = ({ file }: { file?: Partial<File> }) => {
  const router = useRouter()
  const { values, onChange } = useForm<Partial<File> & { file: any }>({ file: undefined, ...file })
  console.log(file)
  const [type, setType] = useState<undefined | string>()
  const [uploadFile, createData] = useUploadFileMutation()
  const [updateFile, updateData] = useUpdateFileMutation()

  function handleFile(event: ChangeEvent<HTMLInputElement>) {
    const loadedFile = event.target.files?.item(0)
    if (!loadedFile) return
    setType(loadedFile.type)
    onChange(customEvent('file', loadedFile))
  }

  return (
    <form
      onSubmit={async (event) => {
        event.preventDefault()
        const { file: loadedFile, ...formData } = values
        const data = prepareDataForDB(formData, file)
        console.log(data, file)
        if (file) {
          const { id, ...others } = data
          updateFile({ variables: { data: others, where: { id: file.id } } })
        } else {
          const uploadResult = await uploadFile({ variables: { ...values, file: loadedFile } })
          if (uploadResult) {
            router.push(`/admin/video/[id]`, `/admin/video/${uploadResult.data?.createFile.id}`)
          }
        }
      }}
    >
      {file ? (
        <>
          <a href={`/${values.path}`} download={values.filename}>
            <FontAwesomeIcon icon={faLink} height={14} />
            {' ' + values.filename}
          </a>
          {file.mimetype?.startsWith('audio') && <PlayButton url={values.path} />}
        </>
      ) : (
        <input name='file' type='file' multiple={false} onChange={handleFile} />
      )}
      <TextInput name='comment' value={values.comment} placeholder='Comment' onChange={onChange} />
      {(type?.startsWith('audio') || file?.mimetype?.startsWith('audio')) && (
        <>
          <TextInput name='artist' value={values.artist} placeholder='Artist' onChange={onChange} />
          <TextInput name='title' value={values.title} placeholder='Title' onChange={onChange} />
        </>
      )}
      {type}
      <button type='submit'>Save file</button>
    </form>
  )
}

export default EditFile
