import {
  useTrainingTypesQuery,
  TrainingType,
  TrainingTypesQuery,
  TrainingTypesQueryVariables,
} from '../../gql'
import Selector from './Selector'

interface ITrainingTypeSelector {
  value?: TrainingType
  onChange: GenericEventHandler
  name?: string
  label?: string
  className?: string
}

const TrainingTypeSelectItem = ({ data }: { data: TrainingType }) => {
  return (
    <div>
      <h3>{data.name}</h3>
      <p>{data.description}</p>
    </div>
  )
}

const TrainingTypeSelector = ({
  value,
  onChange,
  name = 'type',
  label = 'Training type',
  className = 'training-type',
}: ITrainingTypeSelector) => {
  return (
    <Selector<TrainingTypesQuery, TrainingTypesQueryVariables>
      SelectorItem={TrainingTypeSelectItem}
      name={name}
      value={value}
      onChange={onChange}
      query={useTrainingTypesQuery}
      searchKeys={['name_contains', 'description_contains']}
      className={className}
    />
  )
}
export default TrainingTypeSelector
