import { TextInput } from '../../form'
import theme from '../../styles/theme'
import { useState, ChangeEvent } from 'react'
import { FontAwesomeIcon } from '@fortawesome/react-fontawesome'
import { faChevronRight, faChevronDown } from '@fortawesome/free-solid-svg-icons'
import { Video } from '../../gql'
import FileSelector from '../../file/components/FileSelector'

const VideoInstanceInputs = ({
  value,
  name,
  onChange,
  className = 'ei-fields',
}: {
  value: Partial<Video>
  name: string
  onChange: GenericEventHandler
  className?: string
}) => {
  const [show, setShow] = useState(true)

  return (
    <fieldset className={className}>
      {!value.id?.startsWith('++') && (
        <div className='ei-info'>
          <div>Video Instance ID{value.id}</div>
          <div>Created at:</div>
        </div>
      )}
      <TextInput
        name={`${name}.order`}
        label='Order'
        value={value.order}
        type='number'
        onChange={onChange}
        className='vi-order'
      />
      <div className='ei-video'>
        <FontAwesomeIcon
          icon={show ? faChevronDown : faChevronRight}
          height={16}
          onClick={() => setShow(!show)}
        />
        <FileSelector name={`${name}.file`} value={value.file} onChange={onChange} />
      </div>

      <style jsx>{`
        .ei-video > label,
        .ei-video > input[type='radio'] {
          display: inline;
          width: auto;
        }
        @media (min-width: ${theme.midsize}) {
          .${className} {
            display: grid;
            grid-template-areas:
              'info info info info'
              'order  rounds variation variation'
              'video  video  video video'
              'button button button button';
            grid-template-columns: repeat(4, 1fr);
          }

          .${className} :global(.ei-order) {
            grid-area: order;
          }
          .${className} :global(.ei-rounds) {
            grid-area: rounds;
          }
          .${className} :global(.ei-variation) {
            grid-area: variation;
          }
          .${className} :global(.ei-video) {
            grid-area: video;
          }
          .${className} :global(.ei-button) {
            grid-area: button;
          }
        }
      `}</style>
    </fieldset>
  )
}

export default VideoInstanceInputs
